@@ -4,6 +4,7 @@ from dataclasses import dataclass
 from typing import Final, Iterable
 
 from pycommons.io.path import Path, directory_path
+from pycommons.processes.python import PYTHON_ENV
 from pycommons.processes.shell import STREAM_FORWARD, Command
 from pycommons.types import check_int_range, type_error
 
@@ -173,7 +174,8 @@ class BuildInfo:
         :param doc_source_dir: the documentation source directory, if any
         :param doc_dest_dir: the documentation destination directory, if any
         :param dist_dir: the distribution directory, if any
-        :param timeout: the standard timeout
+        :param timeout: the standard timeout in seconds
+        :raises ValueError: if the directories are inconsistent
         """
         object.__setattr__(self, "base_dir", directory_path(base_dir))
         object.__setattr__(self, "package_name", str.strip(package_name))
@@ -234,7 +236,7 @@ class BuildInfo:
         r"""
         Convert this object to a string.
 
-        :return: the string version of this object.
+        :returns: the string version of this object.
 
         >>> str(BuildInfo(Path(__file__).up(4), "pycommons"))[:15]
         "'pycommons' in "
@@ -285,7 +287,15 @@ class BuildInfo:
         """
         Create a typical build step command.
 
+        This command will receive an environment with all the Python-related
+        environment variables that were also passed to the current process.
+        This includes the Path, the Python interpreter's name, as well as
+        information about the virtual environment, if any. This is necessary
+        if we use build tools that were installed in this virtual environment.
+
         :param args: the arguments of the command
+        :param env: the environment to be used with this command
+        :returns: a command relative to the build directories
 
         >>> b = BuildInfo(Path(__file__).up(4), "pycommons")
         >>> cmd = b.command(("cat", "README.txt"))
@@ -303,7 +313,8 @@ class BuildInfo:
         3600
         """
         return Command(args, working_dir=self.base_dir, timeout=self.timeout,
-                       stderr=STREAM_FORWARD, stdout=STREAM_FORWARD)
+                       stderr=STREAM_FORWARD, stdout=STREAM_FORWARD,
+                       env=PYTHON_ENV)
 
 
 def parse_project_arguments(parser: ArgumentParser,
@@ -313,6 +324,8 @@ def parse_project_arguments(parser: ArgumentParser,
 
     :param parser: the argument parser
     :param args: the command line arguments
+    :returns: the build info
+    :raises: TypeError if the types are wrong
 
     >>> from pycommons.io.arguments import pycommons_argparser
     >>> ap = pycommons_argparser(__file__, "a test program",
@@ -428,7 +441,7 @@ def replace_in_cmd(orig: Iterable[str], replace_with: str,
     :param orig: the original sequence
     :param replace_with: the string it is to be replace with
     :param replace_what: the string to be replaced
-    :return: the replaced sequence
+    :returns: the replaced sequence
 
     >>> replace_in_cmd(('x', '.', 'y'), 'a', '.')
     ['x', 'a', 'y']
@@ -445,7 +458,7 @@ def replace_in_cmd(orig: Iterable[str], replace_with: str,
     ...     replace_in_cmd(1, 'a', '.')
     ... except TypeError as te:
     ...     print(te)
-    orig should be an instance of typing.Iterable but is int, namely '1'.
+    orig should be an instance of typing.Iterable but is int, namely 1.
 
     >>> try:
     ...     replace_in_cmd([], 'a', '.')
