@@ -18,7 +18,6 @@ from pycommons.dev.url_replacer import make_url_replacer
 from pycommons.io.arguments import pycommons_argparser
 from pycommons.io.console import logger
 from pycommons.io.path import Path, delete_path
-from pycommons.processes.python import PYTHON_INTERPRETER
 from pycommons.processes.shell import STREAM_CAPTURE, STREAM_FORWARD, Command
 from pycommons.types import type_error
 
@@ -31,7 +30,7 @@ def __get_source(
 
     :param source: the directory
     :param __dst: the destination
-    :return: the set of files
+    :returns: the set of files
 
     >>> from pycommons.io.temp import temp_dir
     >>> with temp_dir() as td:
@@ -136,7 +135,7 @@ def __keep_only_source(
         if f.is_dir():
             __keep_only_source(f, keep, __collect)
     if lst:
-        lst.sort(key=cast(Callable[[Path], int], str.__len__), reverse=True)
+        lst.sort(key=cast("Callable[[Path], int]", str.__len__), reverse=True)
         for k in lst:
             delete_path(k)
 
@@ -157,20 +156,18 @@ def __pygmentize(source: Path, info: BuildInfo,
     ...     doc_source_dir=root.resolve_inside("docs/source"),
     ...     doc_dest_dir=root.resolve_inside("docs/build"))
 
-    >>> from io import StringIO
     >>> from contextlib import redirect_stdout
     >>> from pycommons.io.temp import temp_dir
-    >>> sio = StringIO()
     >>> with temp_dir() as td:
-    ...     with redirect_stdout(sio):
+    ...     with redirect_stdout(None):
     ...         __pygmentize(root.resolve_inside("README.md"), bf, td)
     ...         readme = td.resolve_inside("README_md.html").is_file()
     ...         __pygmentize(root.resolve_inside("setup.py"), bf, td)
     ...         setuppy = td.resolve_inside("setup_py.html").is_file()
     ...         __pygmentize(root.resolve_inside("setup.cfg"), bf, td)
     ...         setup_cfg = td.resolve_inside("setup_cfg.html").is_file()
-    ...         __pygmentize(root.resolve_inside("Makefile"), bf, td)
-    ...         makefile = td.resolve_inside("Makefile.html").is_file()
+    ...         __pygmentize(root.resolve_inside("make.sh"), bf, td)
+    ...         makefile = td.resolve_inside("make_sh.html").is_file()
     ...         __pygmentize(root.resolve_inside("LICENSE"), bf, td)
     ...         xlicense = td.resolve_inside("LICENSE.html").is_file()
     ...         __pygmentize(root.resolve_inside("requirements.txt"), bf, td)
@@ -203,6 +200,8 @@ def __pygmentize(source: Path, info: BuildInfo,
         language = "INI"
     elif name.lower() == "makefile":
         language = "make"
+    elif name.endswith(".sh"):
+        language = "bash"
     if dest is None:
         dest = info.doc_dest_dir
     dest_file: Final[Path] = dest.resolve_inside(
@@ -217,7 +216,7 @@ def __pygmentize(source: Path, info: BuildInfo,
 
 #: the default files to pygmentize
 __PYGMENTIZE_DEFAULT: Final[tuple[str, ...]] = (
-    "conftest.py", "LICENSE", "Makefile", "pyproject.toml",
+    "conftest.py", "LICENSE", "make.sh", "Makefile", "pyproject.toml",
     "requirements.txt", "requirements-dev.txt", "setup.cfg", "setup.py",
 )
 
@@ -263,9 +262,8 @@ def __render_markdown(markdown: Path, info: BuildInfo, dest: Path | None,
     >>> from io import StringIO
     >>> from contextlib import redirect_stdout
     >>> from pycommons.io.temp import temp_dir
-    >>> sio = StringIO()
     >>> with temp_dir() as td:
-    ...     with redirect_stdout(sio):
+    ...     with redirect_stdout(None):
     ...         __render_markdown(root.resolve_inside("README.md"), bf,
     ...             td, None, lambda s: s)
     ...         readme = td.resolve_inside("README_md.html").is_file()
@@ -307,7 +305,7 @@ def __render_markdown(markdown: Path, info: BuildInfo, dest: Path | None,
         body_2 = __HTML_BODY_STYLE_2
 
     text: Final[str] = url_fixer(str.strip(Command((
-        PYTHON_INTERPRETER, "-m", "markdown", "-o", "html", markdown),
+        "markdown_py", "-o", "html", markdown),
         stderr=STREAM_FORWARD, stdout=STREAM_CAPTURE, timeout=info.timeout,
         working_dir=info.base_dir).execute()[0]))
     dest_path.write_all_str(f"{__HTML_HEADER}{title}{body_1}{text}{body_2}")
@@ -330,9 +328,8 @@ def __minify(file: Path) -> None:
     >>> from io import StringIO
     >>> from contextlib import redirect_stdout
     >>> from pycommons.io.temp import temp_dir
-    >>> sio = StringIO()
     >>> with temp_dir() as td:
-    ...     with redirect_stdout(sio):
+    ...     with redirect_stdout(None):
     ...         __render_markdown(root.resolve_inside("README.md"), bf,
     ...             td, None, lambda s: s)
     ...         readme = td.resolve_inside("README_md.html")
@@ -345,10 +342,21 @@ def __minify(file: Path) -> None:
     logger(f"Minifying HTML in {file!r}.")
     text: str = str.strip(file.read_all_str())
     text = str.strip(minify_html.minify(  # pylint: disable=E1101
-        text, do_not_minify_doctype=True,
-        ensure_spec_compliant_unquoted_attribute_values=True,
-        keep_html_and_head_opening_tags=False, minify_css=True,
-        minify_js=True, remove_bangs=True,
+        text,
+        allow_noncompliant_unquoted_attribute_values=False,
+        allow_optimal_entities=True,
+        allow_removing_spaces_between_attributes=True,
+        keep_closing_tags=False,
+        keep_comments=False,
+        keep_html_and_head_opening_tags=False,
+        keep_input_type_text_attr=False,
+        keep_ssi_comments=False,
+        minify_css=True,
+        minify_doctype=False,
+        minify_js=True,
+        preserve_brace_template_syntax=False,
+        preserve_chevron_percent_template_syntax=False,
+        remove_bangs=True,
         remove_processing_instructions=True))
     if "<pre" not in text:
         text = " ".join(map(str.strip, text.splitlines()))
@@ -372,9 +380,8 @@ def __minify_all(dest: Path, skip: Callable[[str], bool]) -> None:
     >>> from io import StringIO
     >>> from contextlib import redirect_stdout
     >>> from pycommons.io.temp import temp_dir
-    >>> sio = StringIO()
     >>> with temp_dir() as td:
-    ...     with redirect_stdout(sio):
+    ...     with redirect_stdout(None):
     ...         __render_markdown(root.resolve_inside("README.md"), bf,
     ...             td, None, lambda s: s)
     ...         readme = td.resolve_inside("README_md.html")
@@ -407,7 +414,7 @@ def __put_nojekyll(dest: Path) -> None:
 
     :param dest: the destination path.
 
-    >>> from pycommons.io.temp import temp_dir
+    >>> from pycommons.io.temp import temp_dir, temp_file
     >>> with temp_dir() as td:
     ...     x = td.resolve_inside("x")
     ...     x.ensure_dir_exists()
@@ -420,6 +427,9 @@ def __put_nojekyll(dest: Path) -> None:
     True
     True
     True
+
+    >>> with temp_file() as tf:
+    ...     __put_nojekyll(tf)  # nothing happens
     """
     if not dest.is_dir():
         return
@@ -442,11 +452,14 @@ def make_documentation(info: BuildInfo) -> None:
     ...     doc_dest_dir=root.resolve_inside("docs/build"))
     >>> from io import StringIO
     >>> from contextlib import redirect_stdout
-    >>> sio = StringIO()
-    >>> with redirect_stdout(sio):
+    >>> with redirect_stdout(None):
     ...     make_documentation(bf)
-    >>> "Finished building documentation" in sio.getvalue()
-    True
+
+    >>> try:
+    ...     make_documentation(1)
+    ... except TypeError as te:
+    ...     print(str(te)[-13:])
+    nt, namely 1.
     """
     if not isinstance(info, BuildInfo):
         raise type_error(info, "info", BuildInfo)
