@@ -240,10 +240,10 @@ class DocInfo:
         if str.__len__(uversion) <= 0:
             raise ValueError(
                 f"Invalid version {version!r}: empty or only white space.")
-        for v in uversion.split("."):
-            try:
+        for v in uversion.split("."):  # noqa: PERF203
+            try:  # noqa: PERF203
                 check_to_int_range(v, "version", 0, 1_000_000_000)
-            except ValueError as ve:
+            except ValueError as ve:  # noqa: PERF203
                 raise ValueError(
                     f"Invalid version {version!r}: "
                     f"{str(ve).removesuffix('.')}.") from ve
@@ -260,7 +260,7 @@ class DocInfo:
         """
         Convert this object to a string.
 
-        :return: the string version of this object.
+        :returns: the string version of this object.
 
         >>> print(str(DocInfo(__file__, "a", "b", "c", "1",
         ...                   12, "https://example.com"))[:40])
@@ -278,13 +278,12 @@ def extract_md_infos(readme_md_file: str) -> tuple[str, int | None]:
     Parse a `README.md` file and find the title and last section index.
 
     :param readme_md_file: the path to the `README.md`
-    :return: a tuple of the title (headline starting with `"# "` (but without
+    :returns: a tuple of the title (headline starting with `"# "` (but without
         the `"# "`), and the last section index, if any)
 
     >>> from os.path import join, dirname
     >>> from contextlib import redirect_stdout
-    >>> from io import StringIO
-    >>> with redirect_stdout(StringIO()):
+    >>> with redirect_stdout(None):
     ...     t = extract_md_infos(join(dirname(dirname(dirname(dirname(
     ...                          __file__)))), "README.md"))
     >>> print(t)
@@ -297,7 +296,7 @@ def extract_md_infos(readme_md_file: str) -> tuple[str, int | None]:
     title: str | None = None
     last_idx: int | None = None
     in_code: bool = False
-    with (readme_md.open_for_read() as rd):
+    with (readme_md.open_for_read() as rd):  # noqa: PERF203
         for orig_line in rd:
             line: str = str.strip(orig_line)  # force string
             # skip all code snippets in the file
@@ -320,9 +319,9 @@ def extract_md_infos(readme_md_file: str) -> tuple[str, int | None]:
                         raise ValueError(f"Got {line!r} after having index.")
                 else:
                     idx_str = str.strip(line[3:doti])
-                    try:
+                    try:  # noqa: PERF203
                         index = check_to_int_range(idx_str, "s", 1, 1000)
-                    except ValueError as ve:
+                    except ValueError as ve:  # noqa: PERF203
                         index = None
                         if last_idx is not None:
                             raise ValueError(
@@ -352,12 +351,11 @@ def parse_version_py(version_file: str,
 
     :param version_file: the path to the version file
     :param version_attr: the version attribute
-    :return: the version string
+    :returns: the version string
 
     >>> from os.path import join, dirname
     >>> from contextlib import redirect_stdout
-    >>> from io import StringIO
-    >>> with redirect_stdout(StringIO()):
+    >>> with redirect_stdout(None):
     ...     s = parse_version_py(join(dirname(dirname(dirname(__file__))),
     ...         "version.py"))
     >>> print(s[:s.rindex(".")])
@@ -396,7 +394,7 @@ def parse_version_py(version_file: str,
     >>> from contextlib import redirect_stdout
     >>> from io import StringIO
     >>> try:
-    ...     with redirect_stdout(StringIO()):
+    ...     with redirect_stdout(None):
     ...         parse_version_py(__file__, "xyz")
     ... except ValueError as ve:
     ...     print(str(ve)[:36])
@@ -449,12 +447,11 @@ def load_doc_info_from_setup_cfg(setup_cfg_file: str) -> DocInfo:
     Load the documentation information from the `setup.cfg` file.
 
     :param setup_cfg_file: the path to the `setup.cfg` file.
-    :return: the documentation information
+    :returns: the documentation information
 
     >>> from os.path import dirname, join
     >>> from contextlib import redirect_stdout
-    >>> from io import StringIO
-    >>> with redirect_stdout(StringIO()):
+    >>> with redirect_stdout(None):
     ...     r = load_doc_info_from_setup_cfg(join(dirname(dirname(dirname(
     ...         dirname(__file__)))), "setup.cfg"))
     >>> r.title
