@@ -16,15 +16,15 @@ from urllib3.response import HTTPResponse  # type: ignore
 from pycommons.io.console import logger
 from pycommons.io.path import UTF8, Path, file_path
 from pycommons.net.url import URL
-from pycommons.strings.tools import replace_str
+from pycommons.strings.string_tools import replace_str
 from pycommons.types import check_int_range, type_error
 
 #: The hosts that somtimes are unreachable from my local machine.
 #: When the test is executed in a GitHub workflow, all hosts should be
-#: reachable.
+#: reachable, except sometimes our institute's website and fsf.org.
 __SOMETIMES_UNREACHABLE_HOSTS: Final[set[str]] = \
-    {"iao.hfuu.edu.cn"} if "GITHUB_JOB" in environ else \
-    {"iao.hfuu.edu.cn", "img.shields.io", "pypi.org", "docs.python.org"}
+    {"fsf.org"} if "GITHUB_JOB" in environ else \
+    {"fsf.org", "img.shields.io", "pypi.org", "docs.python.org"}
 
 #: URLs that we never need to check because they are OK
 __CORRECT_URLS: Final[set[str]] = {
@@ -106,15 +106,21 @@ def __ve(msg: str, text: str, idx: int) -> ValueError:
     return ValueError(f"{msg}: '...{piece}...'")
 
 
-def __make_headers() -> tuple[None | dict[str, str], ...]:
+def __make_headers() -> tuple[dict[str, str] | None, ...]:
     """
     Make the headers.
 
     :returns: the headers
     """
-    headers: list[None | dict[str, str]] = [None]
+    headers: list[dict[str, str] | None] = [None]
     headers.extend(
         {"User-Agent": ua} for ua in (
+            "Mozilla/5.0 (X11; Ubuntu; Linux x86_64; rv:138.0) Gecko/20100101"
+            " Firefox/138.0",
+            "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 ("
+            "KHTML, like Gecko) Chrome/136.0.0.0 Safari/537.36 Edg/136.0.0.0",
+            "Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like"
+            " Gecko) Chrome/136.0.0.0 Safari/537.36",
             "Mozilla/5.0 (X11; Ubuntu; Linux x86_64; rv:106.0) Gecko/20100101"
             " Firefox/106.0",
             "Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like "
@@ -145,7 +151,7 @@ def __make_headers() -> tuple[None | dict[str, str], ...]:
 #: The headers to use for the HTTP requests.
 #: It seems that some websites may throttle requests.
 #: Maybe by using different headers, we can escape this.
-__HEADERS: Final[tuple[None | dict[str, str], ...]] = __make_headers()
+__HEADERS: Final[tuple[dict[str, str] | None, ...]] = __make_headers()
 del __make_headers
 
 
@@ -264,7 +270,7 @@ def __find_fragment_html(body: str, fragment: str, url: URL) -> None:
     ...     __find_fragment_html("<p id='1'>bla</p>", "1", 1)
     ... except TypeError as te:
     ...     print(te)
-    url should be an instance of pycommons.net.url.URL but is int, namely '1'.
+    url should be an instance of pycommons.net.url.URL but is int, namely 1.
 
     >>> try:
     ...     __find_fragment_html("", "1",
@@ -332,11 +338,9 @@ def __check_url(urlstr: str, valid_urls: dict[str, str | None],
     >>> __check_url("tweise@hfuu.edu.cn", vu)
 
     >>> from contextlib import redirect_stdout
-    >>> from io import StringIO
 
-    >>> with redirect_stdout(StringIO()):
+    >>> with redirect_stdout(None):
     ...     __check_url("https://thomasweise.github.io/pycommons", vu)
-    ...     __check_url("http://iao.hfuu.edu.cn", vu)
     ...     __check_url("http://example.com/", vu)
     ...     __check_url("https://thomasweise.github.io/pycommons/pycommons"
     ...                 ".io.html", vu)
@@ -344,8 +348,6 @@ def __check_url(urlstr: str, valid_urls: dict[str, str | None],
     >>> __check_url(
     ...     "https://thomasweise.github.io/pycommons/pycommons.io.html", vu)
 
-    >>> with redirect_stdout(StringIO()):
-    ...     __check_url("http://iao.hfuu.edu.cn/", vu)
     >>> __check_url("https://thomasweise.github.io/pycommons/pycommons"
     ...             ".io.html#pycommons.io.path.Path", vu)
     >>> __check_url("http://example.com", vu)
@@ -356,7 +358,7 @@ def __check_url(urlstr: str, valid_urls: dict[str, str | None],
     ...     print(str(ve)[:50])
     Error in url 'bwri435//sdfsdf:-@@': URL part 'bwri
 
-    >>> with redirect_stdout(StringIO()):
+    >>> with redirect_stdout(None):
     ...     try:
     ...         __check_url(
     ...             "https://thomasweise.github.io/sifwrwruS.jpg#34", vu)
@@ -365,7 +367,7 @@ def __check_url(urlstr: str, valid_urls: dict[str, str | None],
     >>> print(s[:61])
     Url 'https://thomasweise.github.io/sifwrwruS.jpg#34' does not
 
-    >>> with redirect_stdout(StringIO()):
+    >>> with redirect_stdout(None):
     ...     try:
     ...         __check_url("ssh://u@thomasweise.github.io/sifwrwruSSXFd", vu)
     ...     except ValueError as ve:
@@ -373,7 +375,7 @@ def __check_url(urlstr: str, valid_urls: dict[str, str | None],
     >>> print(s)
     Invalid scheme for url 'ssh://u@thomasweise.github.io/sifwrwruSSXFd'.
 
-    >>> with redirect_stdout(StringIO()):
+    >>> with redirect_stdout(None):
     ...     try:
     ...         __check_url(
     ...             "https://thomasweise.github.io/sifwrwruSSXFdfDX", vu)
@@ -404,7 +406,7 @@ def __check_url(urlstr: str, valid_urls: dict[str, str | None],
     ...     __check_url("http://example.com", 1)
     ... except TypeError as te:
     ...     print(te)
-    valid_urls should be an instance of dict but is int, namely '1'.
+    valid_urls should be an instance of dict but is int, namely 1.
 
     >>> try:
     ...     __check_url("http://example.com", dict(), None)
@@ -484,14 +486,14 @@ def __check_url(urlstr: str, valid_urls: dict[str, str | None],
         headers[header_count], headers[header_idx] \
             = header, headers[header_count]
         try:
-            response = cast(HTTPResponse, http.request(
+            response = cast("HTTPResponse", http.request(
                 method, base_url, timeout=timeout, redirect=True,
                 retries=retries, headers=header))
             if isinstance(response, HTTPResponse) and isinstance(
                     response.status, int) and (response.status == 200):
                 error = None
                 break
-        except BaseException as be:  # noqa: B036
+        except BaseException as be:  # noqa
             logger(f"Attempt sleep={sleep_time}, retries={retries}, "
                    f"timeout={timeout}, error={str(be)!r}, and "
                    f"header={header!r} for {base_url!r} gave {be}.")
@@ -510,7 +512,7 @@ def __check_url(urlstr: str, valid_urls: dict[str, str | None],
     if needs_body:
         try:
             body = str.strip(response.data.decode(UTF8))
-        except BaseException as be:    # noqa: B036
+        except BaseException as be:    # noqa
             raise ValueError(f"Error in body of url {url!r}: {be}") from be
 
     body_len: Final[int] = 0 if body is None else str.__len__(body)
