@@ -38,7 +38,16 @@ from os.path import (
 from os.path import basename as osbasename
 from os.path import exists as osexists
 from shutil import rmtree
-from typing import Any, Callable, Final, Iterable, Iterator, TextIO, cast
+from typing import (
+    Any,
+    Callable,
+    Final,
+    Generator,
+    Iterable,
+    Iterator,
+    TextIO,
+    cast,
+)
 
 from pycommons.types import check_int_range, type_error
 
@@ -60,7 +69,7 @@ def _get_text_encoding(filename: str) -> str:
     Adapted from https://stackoverflow.com/questions/13590749.
 
     :param filename: the filename
-    :return: the encoding
+    :returns: the encoding
 
     >>> from tempfile import mkstemp
     >>> from os import close as osxclose
@@ -187,6 +196,9 @@ join(dirname(realpath(getcwd())), "1.txt")
     True
     """
 
+    # see https://docs.astral.sh/ruff/rules/no-slots-in-str-subclass/
+    __slots__ = ()
+
     def __new__(cls, value: Any):  # noqa
         """
         Construct the path object by normalizing the path string.
@@ -233,7 +245,7 @@ join(dirname(realpath(getcwd())), "1.txt")
         Path must not be empty.
         """
         if isinstance(value, Path):
-            return cast(Path, value)
+            return cast("Path", value)
 
         if str.__len__(value) <= 0:
             raise ValueError("Path must not be empty.")
@@ -241,7 +253,7 @@ join(dirname(realpath(getcwd())), "1.txt")
             raise ValueError("Path must not start or end with white space, "
                              f"but {value!r} does.")
         value = normcase(abspath(realpath(expanduser(expandvars(value)))))
-        if (str.__len__(value) <= 0) or (value in [".", ".."]):
+        if (str.__len__(value) <= 0) or (value in {".", ".."}):  # impossible!
             raise ValueError(f"Canonicalization cannot yield {value!r}.")
 
         return super().__new__(cls, value)
@@ -366,7 +378,7 @@ join(dirname(realpath(getcwd())), "1.txt")
         path does not contain `other`.
 
         :param other: the other path
-        :return: `True` is this path contains the other path, `False` of not
+        :returns: `True` is this path contains the other path, `False` of not
 
         >>> from os.path import dirname
         >>> Path(dirname(__file__)).contains(__file__)
@@ -454,7 +466,7 @@ dirname(__file__)))
         :meth:`enforce_contains` and otherwise an error is raised.
 
         :param relative_path: the path to resolve
-        :return: the resolved child path
+        :returns: the resolved child path
         :raises TypeError: If the `relative_path` is not a string.
         :raises ValueError: If the `relative_path` would resolve to something
             outside of this path and/or if it is empty.
@@ -522,7 +534,7 @@ dirname(__file__)))
         here creates the file if it does not exist. The method can only create
         the file if the directory already exists.
 
-        :return: `True` if the file already existed and
+        :returns: `True` if the file already existed and
             `False` if it was newly and atomically created.
         :raises: ValueError if anything goes wrong during the file creation
 
@@ -608,7 +620,7 @@ dirname(__file__)))
         """
         try:
             osclose(osopen(self, O_CREAT | O_TRUNC))
-        except BaseException as err:  # noqa: B036
+        except BaseException as err:  # noqa
             raise ValueError(
                 f"Error when truncating/creating file {self!r}.") from err
         self.enforce_file()
@@ -665,6 +677,77 @@ dirname(__file__)))
                 f"Error when trying to create directory {self!r}.") from err
         self.enforce_dir()
 
+    def ensure_parent_dir_exists(self) -> "Path":
+        """
+        Make sure that the parent directory exists, create it otherwise.
+
+        This path may identify a file or directory to be created that does not
+        yet exist. The parent directory of this path is ensured to exist,
+        i.e., if it already exists, nothing happens, but if it does not yet
+        exist, it is created. If the parent directory cannot be created, a
+        :class:`ValueError` is raised.
+
+        :returns: the parent dir
+        :raises ValueError: if the directory did not exist and creation failed
+
+        >>> from os.path import dirname
+        >>> _ = Path(__file__).ensure_parent_dir_exists()  # nothing happens
+
+        >>> try:
+        ...     _ = Path(join(__file__, "a")).ensure_parent_dir_exists()
+        ... except ValueError as ve:
+        ...     print("does not identify a directory" in str(ve))
+        True
+
+        >>> from tempfile import mkdtemp
+        >>> from os import rmdir as osrmdirx
+        >>> td = mkdtemp()
+        >>> tf = Path(join(td, "xxx"))
+        >>> _ = tf.ensure_parent_dir_exists()
+        >>> osrmdirx(td)
+        >>> isdir(dirname(tf))
+        False
+        >>> _ = tf.ensure_parent_dir_exists()
+        >>> isdir(dirname(tf))
+        True
+        >>> osrmdirx(td)
+
+        >>> td = mkdtemp()
+        >>> isdir(td)
+        True
+        >>> td2 = join(td, "xxx")
+        >>> isdir(td2)
+        False
+        >>> tf = join(td2, "xxx")
+        >>> _ = Path(tf).ensure_parent_dir_exists()
+        >>> isdir(td2)
+        True
+        >>> osrmdirx(td2)
+        >>> osrmdirx(td)
+
+        >>> td = mkdtemp()
+        >>> isdir(td)
+        True
+        >>> td2 = join(td, "xxx")
+        >>> isdir(td2)
+        False
+        >>> td3 = join(td2, "xxx")
+        >>> isdir(td3)
+        False
+        >>> tf = join(td3, "xxx")
+        >>> _ = Path(tf).ensure_parent_dir_exists()
+        >>> isdir(td3)
+        True
+        >>> isdir(td2)
+        True
+        >>> osrmdirx(td3)
+        >>> osrmdirx(td2)
+        >>> osrmdirx(td)
+        """
+        pd: Final[Path] = Path(dirname(self))
+        Path.ensure_dir_exists(pd)
+        return pd
+
     def open_for_read(self) -> TextIOBase:
         r"""
         Open this file for reading text.
@@ -673,7 +756,7 @@ dirname(__file__)))
         and take any encoding error serious. If the path does not identify an
         existing file, an exception is thrown.
 
-        :return: the file open for reading
+        :returns: the file open for reading
         :raises ValueError: if the path does not identify a file
 
         >>> with Path(__file__).open_for_read() as rd:
@@ -691,7 +774,7 @@ dirname(__file__)))
         does not identify a file.
         """
         self.enforce_file()
-        return cast(TextIOBase, open(  # noqa: SIM115
+        return cast("TextIOBase", open(  # noqa: SIM115
             self, encoding=_get_text_encoding(self), errors="strict"))
 
     def read_all_str(self) -> str:
@@ -702,7 +785,7 @@ dirname(__file__)))
         is empty, an exception will be raised. No modification is applied to
         the text that is read.
 
-        :return: the single string of text
+        :returns: the single string of text
         :raises ValueError: if the path does not identify a file or if the
             file it identifies is empty
 
@@ -747,7 +830,7 @@ dirname(__file__)))
 
         If the path cannot be opened for writing, some error will be raised.
 
-        :return: the text io wrapper for writing
+        :returns: the text io wrapper for writing
         :raises ValueError: if the path does not identify a file or such a
             file cannot be created
 
@@ -771,7 +854,7 @@ dirname(__file__)))
         True
         """
         self.ensure_file_exists()
-        return cast(TextIOBase, open(  # noqa: SIM115
+        return cast("TextIOBase", open(  # noqa: SIM115
             self, mode="w", encoding="utf-8", errors="strict"))
 
     def write_all_str(self, contents: str) -> None:
@@ -840,7 +923,7 @@ dirname(__file__)))
         Compute a relative path of this path towards the given base path.
 
         :param base_path: the string
-        :return: a relative path
+        :returns: a relative path
         :raises ValueError: if this path is not inside `base_path` or the
             relativization result is otherwise invalid
 
@@ -876,7 +959,7 @@ dirname(__file__)))
         opath.enforce_contains(self)
         rv: Final[str] = relpath(self, opath)
         if (str.__len__(rv) == 0) or (str.strip(rv) is not rv):
-            raise ValueError(
+            raise ValueError(  # close to impossible
                 f"Invalid relative path {rv!r} resulting from relativizing "
                 f"{self!r} to {base_path!r}={opath!r}.")
         return rv
@@ -891,7 +974,7 @@ dirname(__file__)))
         :param levels: the number levels to go up: `1` for getting the
             directly containing directory, `2` for the next higher directory,
             and so on.
-        :return: the resulting path
+        :returns: the resulting path
 
         >>> f = file_path(__file__)
         >>> print(f.up()[-13:])
@@ -939,7 +1022,7 @@ dirname(__file__)))
         """
         Get the name of the file or directory identified by this path.
 
-        :return: the name of the file or directory
+        :returns: the name of the file or directory
 
         >>> file_path(__file__).basename()
         'path.py'
@@ -962,7 +1045,7 @@ dirname(__file__)))
         """
         List the files and/or sub-directories in this directory.
 
-        :return: an iterable with the fully-qualified paths
+        :returns: an iterable with the fully-qualified paths
 
         >>> from tempfile import mkstemp, mkdtemp
         >>> from os import close as osxclose
@@ -996,7 +1079,7 @@ dirname(__file__)))
         ...     dir1.list_dir(1)
         ... except TypeError as te:
         ...     print(te)
-        files should be an instance of bool but is int, namely '1'.
+        files should be an instance of bool but is int, namely 1.
 
         >>> try:
         ...     dir1.list_dir(True, None)
@@ -1008,7 +1091,7 @@ dirname(__file__)))
         ...     dir1.list_dir(True, 1)
         ... except TypeError as te:
         ...     print(te)
-        directories should be an instance of bool but is int, namely '1'.
+        directories should be an instance of bool but is int, namely 1.
 
         >>> try:
         ...     dir1.list_dir(False, False)
@@ -1039,7 +1122,7 @@ def file_path(pathstr: str) -> "Path":
     :meth:`~Path.enforce_file`.
 
     :param pathstr: the path
-    :return: the file
+    :returns: the file
 
     >>> file_path(__file__)[-20:]
     'pycommons/io/path.py'
@@ -1064,7 +1147,7 @@ def directory_path(pathstr: str) -> "Path":
     :meth:`~Path.enforce_dir`.
 
     :param pathstr: the path
-    :return: the file
+    :returns: the file
 
     >>> from os.path import dirname
     >>> directory_path(dirname(__file__))[-12:]
@@ -1083,7 +1166,7 @@ def directory_path(pathstr: str) -> "Path":
 
 #: the ends-with check
 __ENDSWITH: Final[Callable[[str, str], bool]] = cast(
-    Callable[[str, str], bool], str.endswith)
+    "Callable[[str, str], bool]", str.endswith)
 
 
 def line_writer(output: TextIO | TextIOBase) -> Callable[[str], None]:
@@ -1109,7 +1192,7 @@ def line_writer(output: TextIO | TextIOBase) -> Callable[[str], None]:
     adds the `"\n"` terminator to each of them if necessary.
 
     :param output: the output stream
-    :return: an instance of :class:`typing.Callable` that will write each
+    :returns: an instance of :class:`typing.Callable` that will write each
         string it receives as a properly terminated line to the output
         stream.
     :raises TypeError: if `output` is not an instance of
@@ -1199,7 +1282,7 @@ def line_writer(output: TextIO | TextIOBase) -> Callable[[str], None]:
     ...     line_writer(1)
     ... except TypeError as te:
     ...     print(te)
-    output should be an instance of io.TextIOBase but is int, namely '1'.
+    output should be an instance of io.TextIOBase but is int, namely 1.
 
     >>> try:
     ...     line_writer(None)
@@ -1216,7 +1299,48 @@ def line_writer(output: TextIO | TextIOBase) -> Callable[[str], None]:
         if not b:
             __w("\n")
 
-    return cast(Callable[[str], None], __call)
+    return cast("Callable[[str], None]", __call)
+
+
+def __line_iterator(lines: Iterable[str]) -> Generator[str, None, None]:
+    r"""
+    Iterate over the given lines, adding newlines where needed.
+
+    :param lines: the lines
+    :returns: the generator
+
+    >>> list(__line_iterator([]))
+    []
+
+    >>> list(__line_iterator(['a']))
+    ['a', '\n']
+
+    >>> list(__line_iterator(['a', 'b']))
+    ['a', '\n', 'b', '\n']
+
+    >>> list(__line_iterator(['a\n']))
+    ['a\n']
+
+    >>> list(__line_iterator(['a\n', 'b']))
+    ['a\n', 'b', '\n']
+
+    >>> list(__line_iterator(['a', 'b\n']))
+    ['a', '\n', 'b\n']
+
+    >>> list(__line_iterator(['a\n', 'b\n']))
+    ['a\n', 'b\n']
+
+    >>> try:
+    ...     list(__line_iterator(["a", 1]))
+    ... except TypeError as te:
+    ...     print(te)
+    descriptor 'endswith' for 'str' objects doesn't apply to a 'int' object
+    """
+    for line in lines:
+        b: bool = __ENDSWITH(line, "\n")
+        yield line
+        if not b:
+            yield "\n"
 
 
 def write_lines(lines: Iterable[str], output: TextIO | TextIOBase) -> None:
@@ -1228,16 +1352,16 @@ def write_lines(lines: Iterable[str], output: TextIO | TextIOBase) -> None:
 
     Notice that :meth:`~io.TextIOBase.write` and
     :meth:`~io.IOBase.writelines` of class :class:`io.TextIOBase` do not
-    terminate lines that are written
-    with a `"\n"`. This means that, unless you manually make sure that all
-    lines are terminated by `"\n"`, they get written as a single line instead
-    of multiple lines. To solve this issue conveniently, we provide the
-    functions :func:`line_writer`, which wraps the
-    :meth:`~io.TextIOBase.write` into another function, which automatically
-    terminates all strings passed to it with `"\n"` unless they already end in
-    `"\n"`, and :func:`write_lines`, which iterates over a sequence of strings
-    and writes each of them to a given :class:`typing.TextIO` and automatically
-    adds the `"\n"` terminator to each of them if necessary.
+    terminate lines that are written with a `"\n"`. This means that, unless
+    you manually make sure that all lines are terminated by `"\n"`, they get
+    written as a single line instead of multiple lines. To solve this issue
+    conveniently, we provide the functions :func:`line_writer`, which wraps
+    the :meth:`~io.TextIOBase.write` into another function, which
+    automatically terminates all strings passed to it with `"\n"` unless they
+    already end in `"\n"`, and :func:`write_lines`, which iterates over a
+    sequence of strings and writes each of them to a given
+    :class:`typing.TextIO` and automatically adds the `"\n"` terminator to
+    each of them if necessary.
 
     :param lines: the lines
     :param output: the output
@@ -1354,7 +1478,7 @@ def write_lines(lines: Iterable[str], output: TextIO | TextIOBase) -> None:
     ...     write_lines(123, sio)
     ... except TypeError as te:
     ...     print(te)
-    lines should be an instance of typing.Iterable but is int, namely '123'.
+    lines should be an instance of typing.Iterable but is int, namely 123.
 
     >>> sio = StringIO()
     >>> try:
@@ -1382,25 +1506,19 @@ def write_lines(lines: Iterable[str], output: TextIO | TextIOBase) -> None:
     ...     write_lines("x", 1)
     ... except TypeError as te:
     ...     print(te)
-    output should be an instance of io.TextIOBase but is int, namely '1'.
+    output should be an instance of io.TextIOBase but is int, namely 1.
 
     >>> try:
     ...     write_lines(2, 1)
     ... except TypeError as te:
     ...     print(te)
-    lines should be an instance of typing.Iterable but is int, namely '2'.
+    lines should be an instance of typing.Iterable but is int, namely 2.
     """
     if not isinstance(lines, Iterable):
         raise type_error(lines, "lines", Iterable)
     if not isinstance(output, TextIOBase):
         raise type_error(output, "output", TextIOBase)
-
-    wd: Final[Callable[[str], Any]] = output.write
-    for line in lines:
-        b: bool = __ENDSWITH(line, "\n")
-        wd(line)
-        if not b:
-            wd("\n")
+    output.writelines(__line_iterator(lines))
 
 
 def delete_path(path: str) -> None:
@@ -1450,6 +1568,6 @@ def delete_path(path: str) -> None:
     if isfile(p):
         osremove(p)
     elif isdir(p):
-        rmtree(p, ignore_errors=True, onerror=None)
+        rmtree(p, ignore_errors=True)
     else:
         raise ValueError(f"{path!r} is neither file nor directory.")
