@@ -34,7 +34,7 @@ def _check_url_part(part: Any, forbidden: Pattern) -> str:
 
     :param part: the part
     :param forbidden: the pattern of forbidden text
-    :return: the url as str
+    :returns: the url as str
 
     >>> try:
     ...     _check_url_part("", _FORBIDDEN_IN_RELATIVE_URL)
@@ -74,6 +74,18 @@ def _check_url_part(part: Any, forbidden: Pattern) -> str:
 
     >>> isinstance(_check_url_part("123", _FORBIDDEN_IN_RELATIVE_URL), str)
     True
+
+    >>> try:
+    ...     _check_url_part(3, _FORBIDDEN_IN_RELATIVE_URL)
+    ... except TypeError as te:
+    ...     print(te)
+    descriptor '__len__' requires a 'str' object but received a 'int'
+
+    >>> try:
+    ...     _check_url_part("3", 5)
+    ... except TypeError as te:
+    ...     print(te)
+    first argument must be string or compiled pattern
     """
     if not (0 < str.__len__(part) < 255):
         raise ValueError(f"URL part {part!r} has invalid length {len(part)}.")
@@ -81,7 +93,7 @@ def _check_url_part(part: Any, forbidden: Pattern) -> str:
     if the_match is not None:
         raise ValueError(f"URL part {part!r} contains the forbidden "
                          f"text {the_match.group()!r}.")
-    urlstr: Final[str] = cast(str, part)
+    urlstr: Final[str] = cast("str", part)
     if not urlstr.isascii():
         raise ValueError(
             f"URL part {urlstr!r} contains non-ASCII characters.")
@@ -108,7 +120,7 @@ _ALLOWED_SCHEMES: Final[set] = {"http", "https"}.union(
     _REQUIRE_USER_NAME_SCHEMES)
 
 
-class URL(str):
+class URL(str):  # noqa: SLOT000
     r"""
     A normalized and expanded URL.
 
@@ -539,7 +551,7 @@ class URL(str):
             `value` is already an absolute URL
         """
         if isinstance(value, URL):
-            return cast(URL, value)
+            return cast("URL", value)
 
         url: str = _check_url_part(
             value, _FORBIDDEN_IN_FULL_URL if base_url is None
@@ -549,8 +561,7 @@ class URL(str):
                 base_url, _FORBIDDEN_IN_FULL_URL), url),
                 _FORBIDDEN_IN_FULL_URL)
 
-        if url.endswith("/"):  # strip trailing '/'
-            url = url[:-1]
+        url = url.removesuffix("/")
 
         # normalize mailto URLs that do not contain //
         is_mailto: bool = url.startswith(_MAILTO_2)
